@@ -57,9 +57,11 @@ def last(a,e):
 
             print(round(CR, 3))
             print('满足一致性')
+            print("寻找最大的特征根")
             print(np.max(w))
             print(sorted(w,reverse=True))
             print(max_max)
+            print("计算出特征向量")
             print('特征向量:%s' % w)
             return w
         else:
@@ -87,7 +89,7 @@ def last(a,e):
         ret = (np.transpose(res) * e).sum(axis=1)
         print(ret)
     except TypeError:
-        print('数据有误，可能不满足一致性，请进行修改')
+        print('数据有误，可能不满足一致性，请调整参数矩阵后重试')
     # if __name__ == '__main__':
         # e = np.array(
         #     [[1, 3, 5, 3, 5],
@@ -294,19 +296,22 @@ def yieryidong(aa,day,alpha,late = 1):
     a['mean_2'] = move_smooth(np.array(a['mean_1']), day)
     a['smooth'] = e_smooth(np.array(a['x']), alpha)
     a['smooth2'] = e_smooth(np.array(a['smooth']),alpha)
+    a['smooth3'] = e_smooth(np.array(a['smooth2'],alpha))
     plt.figure(figsize=(15, 7))
     plt.grid(True)
     plt.plot(a["x"])
     plt.savefig("时间序列趋势图.png")
     plt.clf()
     print("首先要进行时间坐标的转换，即转化为时间坐标均值为0")
-    print("二次平均法后以及加总上一次二次指数平滑法")
+    print("二次平均法后以及加总上一次二次指数平滑法之后的数据")
     print(a)
     print("指数平滑法进行预测")
     print("一次指数平滑只能预测以后一个周期")
     e_smooth_next(np.array(a['x']), np.array(a['smooth']), alpha)
     print("二次指数平滑，可以推算出曲线,以下为方程")
     e_smooth_n(np.array(a['smooth']),np.array(a['smooth2']),alpha)
+    print("三次次指数平滑，可以推算出曲线,以下为方程")
+    e_smooth_n(np.array(a['smooth2']), np.array(a['smooth3']), alpha)
     print("二次平均法进行预测往后1期")
     smooth_next(np.array(a['mean_1']), np.array(a['mean_2']), day, late)
     print("一次平均法进行预测往后1期")
